# -*- coding: UTF-8 -*-
"""
Software: LingFeat - Comprehensive Linguistic Features for Readability Assessment
Page: TrSF.py (Tree Structure Features)
License: CC-BY-SA 4.0

Original Author: Bruce W. Lee (이웅성) @brucewlee
Affiliation 1: LXPER AI, Seoul, South Korea
Affiliation 2: University of Pennsylvania, PA, USA
Contributing Author: -
Affiliation : -

References:
>>> Tree Structure features inspired by 
Publication 1: Schwarm, Sarah E., and Mari Ostendorf. "Reading level assessment using support vector machines and statistical language models." Proceedings of the 43rd Annual Meeting of the Association for Computational Linguistics (ACL’05). 2005.
"""

import nltk
from lingfeat.utils import division

def retrieve(SuPar, sent_token_list, n_token, n_sent):
    to_TreeH_C = 0
    to_FTree_C = 0
    for sent in sent_token_list:
        dataset = SuPar.predict([sent], prob=True, verbose=False)
        parsed_tree = dataset.sentences
        nltk_tree = nltk.Tree.fromstring(str(parsed_tree[0]))
        to_TreeH_C += int(nltk_tree.height())
        to_FTree_C += len(nltk_tree.flatten())
    result = {
        "to_TreeH_C": to_TreeH_C,
        "as_TreeH_C": float(division(to_TreeH_C,n_sent)),
        "at_TreeH_C": float(division(to_TreeH_C,n_token)),
        "to_FTree_C": to_FTree_C,
        "as_FTree_C": float(division(to_FTree_C,n_sent)),
        "at_FTree_C": float(division(to_FTree_C,n_token)),
    }
    return result


# -*- coding: UTF-8 -*-
"""
Software: LingFeat - Comprehensive Linguistic Features for Readability Assessment
Page: POSF.py (Part-of-Speech Features)
License: CC-BY-SA 4.0

Original Author: Bruce W. Lee (이웅성) @brucewlee
Affiliation 1: LXPER AI, Seoul, South Korea
Affiliation 2: University of Pennsylvania, PA, USA
Contributing Author: -
Affiliation : -

References:
>>> Part-of-Speech features inspired by 
Publication 1: Feng, Lijun, Noémie Elhadad, and Matt Huenerfauth. "Cognitively motivated features for readability assessment." Proceedings of the 12th Conference of the European Chapter of the ACL (EACL 2009). 2009.
"""

from lingfeat.utils import division
    
def retrieve(NLP_doc, n_token, n_sent):
    to_NoTag_C = 0
    to_VeTag_C = 0
    to_AjTag_C = 0
    to_AvTag_C = 0
    to_SuTag_C = 0
    to_CoTag_C = 0
    to_ContW_C = 0
    to_FuncW_C = 0

    for token in NLP_doc:
        if token.pos_ == "NOUN" or token.pos_ == "VERB" or token.pos_ == "NUM" or token.pos_ == "ADJ" or token.pos_ == "ADV":
            to_ContW_C += 1
        else:
            to_FuncW_C += 1

        if token.pos_ == "NOUN":
            to_NoTag_C += 1
        if token.pos_ == "VERB":
            to_VeTag_C += 1
        if token.pos_ == "ADJ":
            to_AjTag_C += 1
        if token.pos_ == "ADV":
            to_AvTag_C += 1
        if token.pos_ == "SCONJ":
            to_SuTag_C += 1
        if token.pos_ == "CCONJ":
            to_CoTag_C += 1
    
    result = {
        "to_NoTag_C":float(to_NoTag_C),
        "as_NoTag_C":float(division(to_NoTag_C,n_sent)),
        "at_NoTag_C":float(division(to_NoTag_C,n_token)),
        "ra_NoAjT_C":float(division(to_NoTag_C,to_AjTag_C)),
        "ra_NoVeT_C":float(division(to_NoTag_C,to_VeTag_C)),
        "ra_NoAvT_C":float(division(to_NoTag_C,to_AvTag_C)),
        "ra_NoSuT_C":float(division(to_NoTag_C,to_SuTag_C)),
        "ra_NoCoT_C":float(division(to_NoTag_C,to_CoTag_C)),
        "to_VeTag_C":float(to_VeTag_C),
        "as_VeTag_C":float(division(to_VeTag_C,n_sent)),
        "at_VeTag_C":float(division(to_VeTag_C,n_token)),
        "ra_VeAjT_C":float(division(to_VeTag_C,to_AjTag_C)),
        "ra_VeNoT_C":float(division(to_VeTag_C,to_NoTag_C)),
        "ra_VeAvT_C":float(division(to_VeTag_C,to_AvTag_C)),
        "ra_VeSuT_C":float(division(to_VeTag_C,to_SuTag_C)),
        "ra_VeCoT_C":float(division(to_VeTag_C,to_CoTag_C)),
        "to_AjTag_C":float(to_AjTag_C),
        "as_AjTag_C":float(division(to_AjTag_C,n_sent)),
        "at_AjTag_C":float(division(to_AjTag_C,n_token)),
        "ra_AjNoT_C":float(division(to_AjTag_C,to_NoTag_C)),
        "ra_AjVeT_C":float(division(to_AjTag_C,to_VeTag_C)),
        "ra_AjAvT_C":float(division(to_AjTag_C,to_AvTag_C)),
        "ra_AjSuT_C":float(division(to_AjTag_C,to_SuTag_C)),
        "ra_AjCoT_C":float(division(to_AjTag_C,to_CoTag_C)),
        "to_AvTag_C":float(to_AvTag_C),
        "as_AvTag_C":float(division(to_AvTag_C,n_sent)),
        "at_AvTag_C":float(division(to_AvTag_C,n_token)),
        "ra_AvAjT_C":float(division(to_AvTag_C,to_AjTag_C)),
        "ra_AvNoT_C":float(division(to_AvTag_C,to_NoTag_C)),
        "ra_AvVeT_C":float(division(to_AvTag_C,to_VeTag_C)),
        "ra_AvSuT_C":float(division(to_AvTag_C,to_SuTag_C)),
        "ra_AvCoT_C":float(division(to_AvTag_C,to_CoTag_C)),
        "to_SuTag_C":float(to_SuTag_C),
        "as_SuTag_C":float(division(to_SuTag_C,n_sent)),
        "at_SuTag_C":float(division(to_SuTag_C,n_token)),
        "ra_SuAjT_C":float(division(to_SuTag_C,to_AjTag_C)),
        "ra_SuNoT_C":float(division(to_SuTag_C,to_NoTag_C)),
        "ra_SuVeT_C":float(division(to_SuTag_C,to_VeTag_C)),
        "ra_SuAvT_C":float(division(to_SuTag_C,to_AvTag_C)),
        "ra_SuCoT_C":float(division(to_SuTag_C,to_CoTag_C)),
        "to_CoTag_C":float(to_CoTag_C),
        "as_CoTag_C":float(division(to_CoTag_C,n_sent)),
        "at_CoTag_C":float(division(to_CoTag_C,n_token)),
        "ra_CoAjT_C":float(division(to_CoTag_C,to_AjTag_C)),
        "ra_CoNoT_C":float(division(to_CoTag_C,to_NoTag_C)),
        "ra_CoVeT_C":float(division(to_CoTag_C,to_VeTag_C)),
        "ra_CoAvT_C":float(division(to_CoTag_C,to_AvTag_C)),
        "ra_CoSuT_C":float(division(to_CoTag_C,to_SuTag_C)),
        "to_ContW_C":float(to_ContW_C),
        "as_ContW_C":float(division(to_ContW_C,n_sent)),
        "at_ContW_C":float(division(to_ContW_C,n_token)),
        "to_FuncW_C":float(to_FuncW_C),
        "as_FuncW_C":float(division(to_FuncW_C,n_sent)),
        "at_FuncW_C":float(division(to_FuncW_C,n_token)),
        "ra_CoFuW_C":float(division(to_ContW_C,to_FuncW_C)), 
    }
    return result


"""
Software: LingFeat - Comprehensive Linguistic Features for Readability Assessment
Page: utils.py
License: CC-BY-SA 4.0

Original Author: Bruce W. Lee (이웅성) @brucewlee
Affiliation 1: LXPER AI, Seoul, South Korea
Affiliation 2: University of Pennsylvania, PA, USA
Contributing Author: -
Affiliation : -
"""
import re
import math

def division(x, y):
    try:
        result = x/y
    except:
        result = 0
    return result

def nan_check(result):
    for key in result:
        if math.isnan(float(result[key])):
            result[key] = 0
    return result

def count_syllables(word:str):
        return len(
        re.findall('(?!e$)[aeiouy]+', word, re.I) +
        re.findall('^[^aeiouy]*e$', word, re.I)
    )


# -*- coding: UTF-8 -*-
"""
Software: LingFeat - Comprehensive Linguistic Features for Readability Assessment
Page: EnGF.py (Entity Grid Features)
License: CC-BY-SA 4.0

Original Author: Diego Palma @dpalmasan
Affiliation: Evernote
Contributing Author: Bruce W. Lee (이웅성) @brucewlee
Affiliation 1: LXPER AI, Seoul, South Korea
Affiliation 2: University of Pennsylvania, PA, USA

References:
>>> Original Python Code from TRUNAJOD2.0, modified by Bruce W. Lee
Publication 1: Palma, Diego, and John Atkinson. "Coherence-based automatic essay assessment." IEEE Intelligent Systems 33.5 (2018): 26-36.
Repository: <https://github.com/dpalmasan/TRUNAJOD2.0>

>>> S-V-O extraction inspired by an algorithm from
Publication 1: Rusu, Delia, et al. "Triplet extraction from sentences." Proceedings of the 10th International Multiconference” Information Society-IS. 2007.

>>> 16 transition patterns approach obtained from 
Publication 1: Barzilay, Regina, and Mirella Lapata. "Modeling local coherence: An entity-based approach." Computational Linguistics 34.1 (2008): 1-34.
Publication 2: Pitler, Emily, and Ani Nenkova. "Revisiting readability: A unified framework for predicting text quality." Proceedings of the 2008 conference on empirical methods in natural language processing. 2008.

>>> Notations in Dependency Mapping
Publication 1: Barzilay, Regina, and Mirella Lapata. "Modeling local coherence: An entity-based approach." Computational Linguistics 34.1 (2008): 1-34.

>>> Local Coherence (graph-based)
Publication 1: Guinaudeau, Camille, and Michael Strube. "Graph-based local coherence modeling." Proceedings of the 51st Annual Meeting of the Association for Computational Linguistics (Volume 1: Long Papers). 2013.
"""

from lingfeat.utils import division

NOUNS = set(['NOUN', 'PRON', 'PROPN'])

ordered_transitions = [
    'SS', 'SO', 'SX', 'S-', 'OS', 'OO', 'OX', 'O-', 'XS', 'XO',
    'XX', 'X-', '-S', '-O', '-X', '--'
]

def dependency_mapping(dep):
    """
    +-----------+-----------------------------------+
    | EGrid Tag | Dependency Tag                    |
    +===========+===================================+
    | S         | nsub, csubj, csubjpass, dsubjpass |
    +-----------+-----------------------------------+
    | O         | iobj, obj, pobj, dobj             |
    +-----------+-----------------------------------+
    | X         | For any other dependency tag      |
    +-----------+-----------------------------------+
    """
    S = ['nsubj', 'csubj', 'csubjpass', 'dsubjpass']
    O = ['iobj', 'obj', 'pobj', 'dobj']
    if S.count(dep) == 1:
        return 'S'
    if O.count(dep) == 1:
        return 'O'
    return 'X'


class EntityGrid:

    def __init__(self, NLP_doc, n_sent):
        """Construct EntityGrid object."""
        # Initialization
        entity_map = dict()
        entity_grid = dict()
        i = 1
        entity_map['s%d' % i] = []
        entity_features = {
            'SS': 0,
            'SO': 0,
            'SX': 0,
            'S-': 0,
            'OS': 0,
            'OO': 0,
            'OX': 0,
            'O-': 0,
            'XS': 0,
            'XO': 0,
            'XX': 0,
            'X-': 0,
            '-S': 0,
            '-O': 0,
            '-X': 0,
            '--': 0
        }

        # For each sentence, get dependencies and its grammatical role
        for token in NLP_doc:
            if token.pos_ in NOUNS:
                entity_map['s%d' % i].append((token.text.upper(),
                                                token.dep_))
                if token.text.upper() not in entity_grid:
                    entity_grid[token.text.upper()] = ['-'] * n_sent
            i += 1
            entity_map['s%d' % i] = []

        # Last iteration will create an extra element, so I remove it.
        entity_map.pop('s%d' % i)

        # Fill entity grid
        for i in range(n_sent):
            sentence = "s%d" % (i + 1)
            for entity, dep in entity_map[sentence]:
                if entity_grid[entity][i] == '-':
                    entity_grid[entity][i] = dependency_mapping(dep)
                elif dependency_mapping(dep) == 'S':
                    entity_grid[entity][i] = dependency_mapping(dep)
                elif (dependency_mapping(dep) == 'O'
                      and entity_grid[entity][i] == 'X'):
                    entity_grid[entity][i] = dependency_mapping(dep)

        # Compute feature vector, we consider transitions of length 2
        total_transitions = (n_sent - 1) * len(entity_grid.keys())

        for entity in entity_grid:
            for i in range(n_sent - 1):
                # Transition type found (e.g. S-)
                transition = (
                    entity_grid[entity][i] + entity_grid[entity][i + 1])

                # Adding 1 to transition count
                entity_features[transition] += 1

        for prob in entity_features:
            if total_transitions != 0:
                entity_features[prob] /= float(total_transitions)
            else:
                entity_features[prob] = 0.0

        self.grid = entity_grid
        self.n_sent = n_sent
        self.prob = entity_features

    def retrieve(self):
        """
        Retrieve All
        """
        result = {}
        result['ra_SSTo_C'] = self.prob['SS']
        result['ra_SOTo_C'] = self.prob['SO']
        result['ra_SXTo_C'] = self.prob['SX']
        result['ra_SNTo_C'] = self.prob['S-']
        result['ra_OSTo_C'] = self.prob['OS']
        result['ra_OOTo_C'] = self.prob['OO']
        result['ra_OXTo_C'] = self.prob['OX']
        result['ra_ONTo_C'] = self.prob['O-']
        result['ra_XSTo_C'] = self.prob['XS']
        result['ra_XOTo_C'] = self.prob['XO']
        result['ra_XXTo_C'] = self.prob['XX']
        result['ra_XNTo_C'] = self.prob['X-']
        result['ra_NSTo_C'] = self.prob['-S']
        result['ra_NOTo_C'] = self.prob['-O']
        result['ra_NXTo_C'] = self.prob['-X']
        result['ra_NNTo_C'] = self.prob['--']
        lcresult = get_local_coherence(self)
        return {**result, **lcresult}

def weighting_syntactic_role(entity_role):
    """
    Return weight given an entity grammatical role.
    +-----------+--------+
    | EGrid Tag | Weight |
    +===========+========+
    | S         | 3      |
    +-----------+--------+
    | O         | 2      |
    +-----------+--------+
    | X         | 1      |
    +-----------+--------+
    | dash      | 0      |
    +-----------+--------+
    """
    if entity_role == u"S":
        return 3
    elif entity_role == u"O":
        return 2
    elif entity_role == u"X":
        return 1

    return 0

def get_local_coherence(EntityGrid):
    local_coherence_PU = 0.0        #lcPA
    local_coherence_PW = 0.0        #lcPW
    local_coherence_PA = 0.0        #lcPU
    local_coherence_PU_dist = 0.0   #lcdPA
    local_coherence_PW_dist = 0.0   #lcdPW
    local_coherence_PA_dist = 0.0   #lcdPU

    n_sent = EntityGrid.n_sent
    grid = EntityGrid.grid

    PW = [[0] * n_sent for i in range(n_sent)]

    # Weight Matrix for PACC, syntactic information is accounted for by
    # integrating the edges of the bipartite graph
    W = [[0] * n_sent for i in range(n_sent)]

    for entity in grid:
        for i in range(n_sent):
            for j in range(i + 1, n_sent):
                if grid[entity][i] != u"-" and grid[entity][j] != u"-":
                    PW[i][j] += 1
                    W[i][j] += (weighting_syntactic_role(grid[entity][i]) *
                                weighting_syntactic_role(grid[entity][j]))

    PU = [list(map(lambda x: x != 0, PWi)) for PWi in PW]

    for i in range(n_sent):
        local_coherence_PW += sum(PW[i])
        local_coherence_PU += sum(PU[i])
        local_coherence_PA += sum(W[i])

    local_coherence_PW /= n_sent
    local_coherence_PU /= n_sent
    local_coherence_PA /= n_sent

    # Weighting projection graphs
    PU_weighted = list(PU)
    PW_weighted = list(PW)
    PA_weighted = list(W)
    for i in range(n_sent):
        for j in range(i + 1, n_sent):
            PU_weighted[i][j] = division(PU[i][j],float(j - i))
            PW_weighted[i][j] = division(PW[i][j],float(j - i))
            PA_weighted[i][j] = division(W[i][j],float(j - i))

    for i in range(n_sent):
        local_coherence_PW_dist += sum(PW_weighted[i])
        local_coherence_PU_dist += sum(PU_weighted[i])
        local_coherence_PA_dist += sum(PA_weighted[i])

    local_coherence_PW_dist /= n_sent
    local_coherence_PU_dist /= n_sent
    local_coherence_PA_dist /= n_sent

    result = {
        'LoCohPA_S':local_coherence_PU,        
        'LoCohPW_S':local_coherence_PW,
        'LoCohPU_S':local_coherence_PA,
        'LoCoDPA_S':local_coherence_PU_dist,
        'LoCoDPW_S':local_coherence_PW_dist,
        'LoCoDPU_S':local_coherence_PA_dist,
    }
    return result


# -*- coding: UTF-8 -*-
"""
Software: LingFeat - Comprehensive Linguistic Features for Readability Assessment
Page: PstF.py (Psycholinguistic Features)
License: CC-BY-SA 4.0

Original Author: Bruce W. Lee (이웅성) @brucewlee
Affiliation 1: LXPER AI, Seoul, South Korea
Affiliation 2: University of Pennsylvania, PA, USA
Contributing Author: -
Affiliation : -


References:
>>> Psycholinguistic features inspired by 
Publication 1: Kuperman, Victor, Hans Stadthagen-Gonzalez, and Marc Brysbaert. "Age-of-acquisition ratings for 30,000 English words." Behavior research methods 44.4 (2012): 978-990.
Publication 2: Vajjala, Sowmya, and Detmar Meurers. "Readability-based sentence ranking for evaluating text simplification." (2015).
"""

import pandas as pd

def retrieve(token_list, n_token, n_sent, dir_path):
    to_AAKuW_C = 0
    to_AAKuL_C = 0
    to_AABiL_C = 0
    to_AABrL_C = 0
    to_AACoL_C = 0

    DB = pd.read_csv(dir_path+'/_LexicoSemantic/resources/AoAKuperman.csv')
    DB.set_index('Word', inplace=True, drop=True)
    for token in token_list:
        if token in DB.index:
            scores_for_this_token = list(DB.loc[token, :])
            for i, score in enumerate(scores_for_this_token):
                scores_for_this_token[i] = 0 if str(score) == 'none' else scores_for_this_token[i]
            to_AAKuW_C += float(scores_for_this_token[7])
            to_AAKuL_C += float(scores_for_this_token[9])
            to_AABiL_C += float(scores_for_this_token[11])
            to_AABrL_C += float(scores_for_this_token[12])
            to_AACoL_C += float(scores_for_this_token[13])

    result = {
        "to_AAKuW_C": to_AAKuW_C,
        "as_AAKuW_C": to_AAKuW_C/n_sent ,
        "at_AAKuW_C": to_AAKuW_C/n_token,
        "to_AAKuL_C": to_AAKuL_C,
        "as_AAKuL_C": to_AAKuL_C/n_sent ,
        "at_AAKuL_C": to_AAKuL_C/n_token,
        "to_AABiL_C": to_AABiL_C,
        "as_AABiL_C": to_AABiL_C/n_sent ,
        "at_AABiL_C": to_AABiL_C/n_token,
        "to_AABrL_C": to_AABrL_C,
        "as_AABrL_C": to_AABrL_C/n_sent ,
        "at_AABrL_C": to_AABrL_C/n_token,
        "to_AACoL_C": to_AABrL_C,
        "as_AACoL_C": to_AABrL_C/n_sent ,
        "at_AACoL_C": to_AABrL_C/n_token,
    }
    return result   


# -*- coding: UTF-8 -*-
"""
Software: LingFeat - Comprehensive Linguistic Features for Readability Assessment
Page: PhrF.py (Phrasal Features)
License: CC-BY-SA 4.0

Original Author: Bruce W. Lee (이웅성) @brucewlee
Affiliation 1: LXPER AI, Seoul, South Korea
Affiliation 2: University of Pennsylvania, PA, USA
Contributing Author: -
Affiliation : -

References:
>>> Phrasal features inspired by 
Publication 1: Feng, Lijun, Martin Jansche, Matt Huenerfauth, and Noémie Elhadad. "A Comparison of Features for Automatic Readability Assessment." In Coling 2010: Posters, pp. 276-284. 2010.
Publication 2: Lu, Xiaofei. "Automatic analysis of syntactic complexity in second language writing." International journal of corpus linguistics 15, no. 4 (2010): 474-496.
"""
from lingfeat.utils import division

def retrieve(SuPar, sent_token_list, n_token, n_sent):
    to_NoPhr_C = 0
    to_VePhr_C = 0
    to_SuPhr_C = 0
    to_PrPhr_C = 0
    to_AjPhr_C = 0
    to_AvPhr_C = 0
    for sent in sent_token_list:

        dataset = SuPar.predict([sent], prob=True, verbose=False)
        parsed_tree = str(dataset.sentences)
        to_NoPhr_C += parsed_tree.count("NP")
        to_VePhr_C += parsed_tree.count("VP")
        to_SuPhr_C += parsed_tree.count("SBAR")
        to_PrPhr_C += parsed_tree.count("PP")
        to_AjPhr_C += parsed_tree.count("ADJP")
        to_AvPhr_C += parsed_tree.count("ADVP")
    result = {
        "to_NoPhr_C": to_NoPhr_C,
        "as_NoPhr_C": float(division(to_NoPhr_C,n_sent)),
        "at_NoPhr_C": float(division(to_NoPhr_C,n_token)),
        "ra_NoVeP_C": float(division(to_NoPhr_C,to_VePhr_C)),
        "ra_NoSuP_C": float(division(to_NoPhr_C,to_SuPhr_C)),
        "ra_NoPrP_C": float(division(to_NoPhr_C,to_PrPhr_C)),
        "ra_NoAjP_C": float(division(to_NoPhr_C,to_AjPhr_C)),
        "ra_NoAvP_C": float(division(to_NoPhr_C,to_AvPhr_C)),

        "to_VePhr_C": to_VePhr_C,
        "as_VePhr_C": float(division(to_VePhr_C,n_sent)),
        "at_VePhr_C": float(division(to_VePhr_C,n_token)),
        "ra_VeNoP_C": float(division(to_VePhr_C,to_NoPhr_C)),
        "ra_VeSuP_C": float(division(to_VePhr_C,to_SuPhr_C)),
        "ra_VePrP_C": float(division(to_VePhr_C,to_PrPhr_C)),
        "ra_VeAjP_C": float(division(to_VePhr_C,to_AjPhr_C)),
        "ra_VeAvP_C": float(division(to_VePhr_C,to_AvPhr_C)),

        "to_SuPhr_C": to_SuPhr_C,
        "as_SuPhr_C": float(division(to_SuPhr_C,n_sent)),
        "at_SuPhr_C": float(division(to_SuPhr_C,n_token)),
        "ra_SuNoP_C": float(division(to_SuPhr_C,to_NoPhr_C)),
        "ra_SuVeP_C": float(division(to_SuPhr_C,to_VePhr_C)),
        "ra_SuPrP_C": float(division(to_SuPhr_C,to_PrPhr_C)),
        "ra_SuAjP_C": float(division(to_SuPhr_C,to_AjPhr_C)),
        "ra_SuAvP_C": float(division(to_SuPhr_C,to_AvPhr_C)),

        "to_PrPhr_C": to_PrPhr_C,
        "as_PrPhr_C": float(division(to_PrPhr_C,n_sent)),
        "at_PrPhr_C": float(division(to_PrPhr_C,n_token)),
        "ra_PrNoP_C": float(division(to_PrPhr_C,to_NoPhr_C)),
        "ra_PrVeP_C": float(division(to_PrPhr_C,to_VePhr_C)),
        "ra_PrSuP_C": float(division(to_PrPhr_C,to_SuPhr_C)),
        "ra_PrAjP_C": float(division(to_PrPhr_C,to_AjPhr_C)),
        "ra_PrAvP_C": float(division(to_PrPhr_C,to_AvPhr_C)),

        "to_AjPhr_C": to_AjPhr_C,
        "as_AjPhr_C": float(division(to_AjPhr_C,n_sent)),
        "at_AjPhr_C": float(division(to_AjPhr_C,n_token)),
        "ra_AjNoP_C": float(division(to_AjPhr_C,to_NoPhr_C)),
        "ra_AjVeP_C": float(division(to_AjPhr_C,to_VePhr_C)),
        "ra_AjSuP_C": float(division(to_AjPhr_C,to_SuPhr_C)),
        "ra_AjPrP_C": float(division(to_AjPhr_C,to_PrPhr_C)),
        "ra_AjAvP_C": float(division(to_AjPhr_C,to_AvPhr_C)),

        "to_AvPhr_C": to_AvPhr_C,
        "as_AvPhr_C": float(division(to_AvPhr_C,n_sent)),
        "at_AvPhr_C": float(division(to_AvPhr_C,n_token)),
        "ra_AvNoP_C": float(division(to_AvPhr_C,to_NoPhr_C)),
        "ra_AvVeP_C": float(division(to_AvPhr_C,to_VePhr_C)),
        "ra_AvSuP_C": float(division(to_AvPhr_C,to_SuPhr_C)),
        "ra_AvPrP_C": float(division(to_AvPhr_C,to_PrPhr_C)),
        "ra_AvAjP_C": float(division(to_AvPhr_C,to_AjPhr_C)),
    }
    return result







